HlsMasterPlaylist class
HLS master playlist parsed from a remote M3U8 URL.
Constructors
-
HlsMasterPlaylist({required List<
String> mediaPlaylistUrls}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mediaPlaylistUrls
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited