VideoCaching class
Pre-cache and cache-check API (delegates to Rust).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isCached(
String url, {Map< String, Object> ? headers, int cacheSegments = 2}) → Future<bool> -
parseHlsMasterPlaylist(
String url, {Map< String, Object> ? headers}) → Future<HlsMasterPlaylist?> -
precache(
String url, {Map< String, Object> ? headers, int cacheSegments = 2, bool downloadNow = true, bool progressListen = false}) → Future<Stream< PrecacheProgressEvent> ?>